@@ -7,13 +7,12 @@
 #' @param ... Further named args to \code{\link[httr]{GET}}
 #' @examples \dontrun{
 #' gists()[[1]] %>% commits()
-#' gist(id='1f399774e9ecc9153a6f') %>% commits(per_page=2)
+#' gist(id = '1f399774e9ecc9153a6f') %>% commits(per_page = 5)
 #' }
 
-commits <- function(gist, page=NULL, per_page=30, ...)
-{
+commits <- function(gist, page=NULL, per_page=30, ...) {
   gist <- as.gist(gist)
-  args <- gist_compact(list(page=page, per_page=per_page))
+  args <- gist_compact(list(page = page, per_page = per_page))
   res <- gist_GET(sprintf('%s/gists/%s/commits', ghbase(), gist$id), gist_auth(), ghead(), args, ...)
   lapply(res, structure, class = "commit")
 }
